pub struct BreakerConfig {
pub window: usize,
pub failure_threshold: usize,
pub cooldown: Duration,
}Expand description
Tunable thresholds. Defaults are deliberately lenient so healthy packages with occasional hiccups are never tripped.
Fields
window: usizeSliding window size (most recent N outcomes considered).
failure_threshold: usizeNumber of failures within the window required to trip Open.
cooldown: DurationHow long to stay Open before allowing a HalfOpen probe.